@@ -1658,7 +1658,7 @@ resource_buffer_switch (const gchar *graph,
 		g_value_init (&gvalue, G_TYPE_INT);
 		g_value_set_int (&gvalue, tracker_data_update_get_next_modseq ());
 		cache_insert_value ("rdfs:Resource", "tracker:modified", &gvalue,
-		                    graph_id,
+		                    0,
 		                    FALSE, FALSE, FALSE);
 	}
 }
@@ -1918,7 +1918,6 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 		/* add value to metadata database */
 		change = cache_set_metadata_decomposed (property, object, 0, graph, 0, &actual_error);
 		if (actual_error) {
-			tracker_data_update_buffer_clear ();
 			g_propagate_error (error, actual_error);
 			return;
 		}
@@ -1989,7 +1988,6 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 	/* add value to metadata database */
 	change = cache_set_metadata_decomposed (property, object, 0, graph, 0, &actual_error);
 	if (actual_error) {
-		tracker_data_update_buffer_clear ();
 		g_propagate_error (error, actual_error);
 		return;
 	}
@@ -2819,7 +2817,6 @@ tracker_data_replay_journal (GHashTable          *classes,
 						cache_set_metadata_decomposed (property, NULL, object_id, NULL, graph_id, &new_error);
 
 						if (new_error) {
-							tracker_data_update_buffer_clear ();
 							g_warning ("Journal replay error: '%s'", new_error->message);
 							g_error_free (new_error);
 						}
