@@ -72,11 +72,13 @@ struct TrackerDBInterfaceIface {
 	GTypeInterface iface;
 
 	TrackerDBStatement * (* create_statement) (TrackerDBInterface  *interface,
+	                                           GError             **error,
 	                                           const gchar         *query);
 	TrackerDBResultSet * (* execute_query)    (TrackerDBInterface  *interface,
 	                                           GError             **error,
 	                                           const gchar         *query);
 	gboolean             (* interrupt)        (TrackerDBInterface  *interface);
+	void                 (* reset_interrupt)  (TrackerDBInterface  *interface);
 };
 
 struct TrackerDBStatementIface {
@@ -139,8 +141,9 @@ GType               tracker_db_result_set_get_type         (void);
 
 /* Functions to create queries/procedures */
 TrackerDBStatement *tracker_db_interface_create_statement  (TrackerDBInterface   *interface,
-                                                            const gchar                *query,
-                                                            ...) G_GNUC_PRINTF (2, 3);
+                                                            GError              **error,
+                                                            const gchar          *query,
+                                                            ...) G_GNUC_PRINTF (3, 4);
 TrackerDBResultSet *tracker_db_interface_execute_vquery    (TrackerDBInterface   *interface,
                                                             GError              **error,
                                                             const gchar          *query,
@@ -151,6 +154,7 @@ TrackerDBResultSet *tracker_db_interface_execute_query     (TrackerDBInterface
                                                             ...) G_GNUC_PRINTF (3, 4);
 
 gboolean            tracker_db_interface_interrupt         (TrackerDBInterface  *interface);
+void                tracker_db_interface_reset_interrupt   (TrackerDBInterface  *interface);
 gboolean            tracker_db_interface_start_transaction (TrackerDBInterface  *interface);
 gboolean            tracker_db_interface_end_db_transaction(TrackerDBInterface  *interface);
 void                tracker_db_statement_bind_double       (TrackerDBStatement  *stmt,
