@@ -62,6 +62,8 @@
 	"\n" \
 	"  http://www.gnu.org/licenses/gpl.txt\n"
 
+#define SECONDS_PER_DAY 60 * 60 * 24
+
 static GMainLoop *main_loop;
 static GSList *miners;
 static GSList *current_miner;
@@ -139,6 +141,7 @@ signal_handler (int signo)
 		in_loop = TRUE;
 		g_main_loop_quit (main_loop);
 
+		/* Fall through */
 	default:
 		if (g_strsignal (signo)) {
 			g_print ("\n");
@@ -179,7 +182,7 @@ initialize_priority (void)
 	 * so complains if we do not check its returned value. But it
 	 * seems that since glibc 2.2.4, nice() can return -1 on a
 	 * successful call so we have to check value of errno too.
-	 * Stupid... 
+	 * Stupid...
 	 */
 	g_message ("Setting process priority");
 
@@ -191,6 +194,42 @@ initialize_priority (void)
 	}
 }
 
+static gboolean
+should_crawl (TrackerConfig *config)
+{
+	gint crawling_interval;
+
+	crawling_interval = tracker_config_get_crawling_interval (config);
+
+	g_message ("Checking whether to perform mtime checks during crawling:");
+
+	if (crawling_interval == -1) {
+		g_message ("  Disabled");
+		return FALSE;
+	} else if (crawling_interval == 0) {
+		g_message ("  Enabled");
+		return TRUE;
+	} else {
+		guint64 then, now;
+		
+		then = tracker_db_manager_get_last_crawl_done ();
+
+		if (then < 1) {
+			return TRUE;
+		}
+
+		now = (guint64) time (NULL);
+
+		if (now < then + (crawling_interval * SECONDS_PER_DAY)) {
+			g_message ("  Postponed");
+			return FALSE;
+		} else {
+			g_message ("  (More than) %d days after last crawling, enabled", crawling_interval);
+			return FALSE;
+		}
+	}
+}
+
 static void
 miner_handle_next (void)
 {
@@ -241,6 +280,11 @@ miner_finished_cb (TrackerMinerFS *fs,
 		return;
 	}
 
+	if (TRACKER_IS_MINER_FILES (fs) &&
+	    tracker_miner_fs_get_initial_crawling (fs)) {
+		tracker_db_manager_set_last_crawl_done (TRUE);
+	}
+
 	miner_handle_next ();
 }
 
@@ -564,9 +608,6 @@ main (gint argc, gchar *argv[])
 		tracker_config_set_initial_sleep (config, initial_sleep);
 	}
 
-	/* Make sure we initialize DBus, this shows we are started
-	 * successfully when called upon from the daemon.
-	 */
 	tracker_log_init (tracker_config_get_verbosity (config),
 	                  &log_filename);
 	g_print ("Starting log:\n  File:'%s'\n", log_filename);
@@ -574,22 +615,9 @@ main (gint argc, gchar *argv[])
 
 	sanity_check_option_values (config);
 
-	/* Set IO priority */
-	tracker_ioprio_init ();
-
-	/* nice() uses attribute "warn_unused_result" and so complains
-	 * if we do not check its returned value. But it seems that
-	 * since glibc 2.2.4, nice() can return -1 on a successful
-	 * call so we have to check value of errno too. Stupid...
+	/* Make sure we initialize DBus, this shows we are started
+	 * successfully when called upon from the daemon.
 	 */
-	if (nice (19) == -1 && errno) {
-		const gchar *str;
-
-		str = g_strerror (errno);
-		g_message ("Couldn't set nice value to 19, %s",
-		           str ? str : "no error given");
-	}
-
 	if (!tracker_dbus_init ()) {
 		g_object_unref (config);
 		tracker_log_shutdown ();
@@ -601,6 +629,8 @@ main (gint argc, gchar *argv[])
 
 	if (!add_file) {
 		miner_files = tracker_miner_files_new (config);
+		tracker_miner_fs_set_initial_crawling (TRACKER_MINER_FS (miner_files),
+		                                       should_crawl (config));
 	} else {
 		GFile *file;
 
